@@ -10,6 +10,8 @@ pub mod models;
 pub mod schema;
 mod utils;
 
+pub type NxtnoteSaveFile = SqliteConnection;
+
 pub fn initialize_file(conn: &SqliteConnection) {
     sql_query(
         "\
@@ -40,7 +42,7 @@ pub fn initialize_file(conn: &SqliteConnection) {
     .unwrap();
 }
 
-pub fn establish_connection(file: String) -> SqliteConnection {
+pub fn establish_connection(file: String) -> NxtnoteSaveFile {
     let connection = SqliteConnection::establish(&file).expect(&format!("Error connecting to {}", file));
 
     sql_query("PRAGMA foreign_keys = ON").execute(&connection).unwrap();
